==============
 ``zope.tal``
==============

.. image:: https://img.shields.io/pypi/v/zope.tal.svg
        :target: https://pypi.python.org/pypi/zope.tal/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.tal.svg
        :target: https://pypi.org/project/zope.tal/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.tal.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.tal

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.tal/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.tal?branch=master

The Zope3 Template Attribute Languate (TAL) specifies the custom namespace
and attributes which are used by the Zope Page Templates renderer to inject
dynamic markup into a page.  It also includes the Macro Expansion for TAL
(METAL) macro language used in page assembly.

The dynamic values themselves are specified using a companion language,
TALES (see the `zope.tales`_ package for more).

See: http://wiki.zope.org/ZPT/TALSpecification14

.. _`zope.tales` :  http://pypi.python.org/pypi/zope.tales
